### Description

Please add a description of the changes proposed in the pull request.

### Checklist

- [ ] Add a reference to related issues.
- [ ] @mentions of the person or team responsible for reviewing proposed changes.
- [ ] This pull request has a descriptive title.
- [ ] Follow [contributing guide](https://pystemmusscope.readthedocs.io/en/latest/CONTRIBUTING/).
- [ ] The checks, below the pull request, are successful (green).
- [ ] Add documentation.
- [ ] Add tests.
- [ ] Add changes to the [changelog file](./docs/CHANGELOG.md) under section `Unreleased`.
- [ ] If your changes are about BMI, make sure that your changes are compatible
  with [the latest version of STEMMUS_SCOPE](https://github.com/EcoExtreML/STEMMUS_SCOPE/releases)
  and [its docker image](https://github.com/orgs/EcoExtreML/packages?repo_name=STEMMUS_SCOPE).
